#ifndef EEPROM_H
#define EEPROM_H

// The base address of the IC EEPROMs.
#define EEPROM_BASE_ADDRESS ((u8)0xA0)

// The size of the IC EEPROMs in bytes.
#define EEPROM_SIZE ((u16)32768)

// The size of a circular buffer used to store upcoming bytes.
#define EEPROM_BUFFER_SIZE (32)

// Initialises the IC periperal for reading from the EEPROM.
void EEPROM_Init(void);

// Start reading from the IC EEPROM at a particular address.
void EEPROM_StartReading(u16 address);

// Read from the IC EEPROM at a particular address.
u8 EEPROM_ReadByte(void);

// Stop reading from the IC EEPROM.
void EEPROM_StopReading(void);

// Seek to a new address in the IC EEPROM.
void EEPROM_Seek(u16 address);

// Reads a byte from the buffer if available, directly from the EEPROM if not.
u8 EEPROM_ReadByteBuffered(void);

// Read a byte from the EEPROM directly and top up the buffer with it if the buffer is not already full.
void EEPROM_TopUpBuffer(void);

// Read a byte directly from a particular address.
u8 EEPROM_ReadByteAt(u16 address);

// Read an unsigned short (16 bits) directly from a particular address.
u16 EEPROM_ReadUShortAt(u16 address);

// Read an unsigned integer (32 bits) directly from a particular address.
u32 EEPROM_ReadUIntAt(u16 address);

#endif